@@ -175,6 +175,8 @@ class BaseReader(ABC):
                 getattr(self, reader)()
             except FileNotFoundError:
                 print("The file is not found for {}".format(reader))
+            except Exception as a:
+                raise Exception(f"Error while reading {reader}")
 
 
 class XlsxReader(BaseReader):
